@@ -6,7 +6,8 @@ eval "$(./conda/bin/conda shell.bash hook)"
 conda activate ./env
 
 python -m torch.utils.collect_env
-export TORCHAUDIO_TEST_FAIL_IF_NO_EXTENSION=1
+env | grep TORCHAUDIO || true
+
 export PATH="${PWD}/third_party/install/bin/:${PATH}"
 
 declare -a args=(
@@ -18,3 +19,4 @@ declare -a args=(
 
 cd test
 pytest "${args[@]}" torchaudio_unittest
+coverage html
