@@ -5,7 +5,7 @@
 #
 # Do not install PyTorch and torchaudio here, otherwise they also get cached.
 
-set -e
+set -ex
 
 root_dir="$(git rev-parse --show-toplevel)"
 conda_dir="${root_dir}/conda"
@@ -21,13 +21,19 @@ esac
 # 1. Install conda at ./conda
 if [ ! -d "${conda_dir}" ]; then
     printf "* Installing conda\n"
-    wget -O miniconda.sh "http://repo.continuum.io/miniconda/Miniconda3-latest-${os}-x86_64.sh"
+    curl --silent -L -o miniconda.sh "http://repo.continuum.io/miniconda/Miniconda3-latest-${os}-x86_64.sh"
     bash ./miniconda.sh -b -f -p "${conda_dir}"
 fi
-eval "$(${conda_dir}/bin/conda shell.bash hook)"
+eval "$("${conda_dir}/bin/conda" shell.bash hook)"
+
 
 # 2. Create test environment at ./env
 if [ ! -d "${env_dir}" ]; then
-    printf "* Creating a test environment\n"
-    conda create --prefix "${env_dir}" -y python="$PYTHON_VERSION"
+    printf "* Creating a test environment with PYTHON_VERSION=%s\n" "${PYTHON_VERSION}\n"
+    conda create --prefix "${env_dir}" -y python="${PYTHON_VERSION}"
 fi
+conda activate "${env_dir}"
+
+# 3. Install minimal build tools
+pip --quiet install cmake ninja
+conda install --quiet -y 'ffmpeg>=4.1' pkg-config
